Ephemeral Keys Certification Authority (EKCA) service
=====================================================

This module package implements the server component of
[EKCA](https://ekca.stroeder.com) which is basically
a simple web service.
